==> libyami-0.3.1.tar.gz: libyami-libyami-0.3.1/vpp/vaapipostprocess_base.cpp <==
/*
 *  vaapipostprocess_base.cpp - basic class for vpp
 *
 *  Copyright (C) 2013-2014 Intel Corporation
 *    Author: Wind Yuan <feng.yuan@intel.com>
 *    Author: Xu Guangxin <guangxin.xu@intel.com>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public License
 *  as published by the Free Software Foundation; either version 2.1
 *  of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301 USA
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "vaapipostprocess_base.h"
#include "common/log.h"
#include "vaapi/vaapidisplay.h"
#include "vaapi/vaapicontext.h"
#include "vaapi/vaapiutils.h"

namespace YamiMediaCodec{

YamiStatus  VaapiPostProcessBase::setNativeDisplay(const NativeDisplay& display)
{
    return initVA(display);
}

YamiStatus VaapiPostProcessBase::initVA(const NativeDisplay& display)
{
    if (m_context) {
        ERROR("do not init va more than one time");
        return YAMI_FAIL;
    }
    if (display.type != NATIVE_DISPLAY_VA
        || !display.handle) {
        ERROR("vpp only support va display as NativeDisplay");
        return YAMI_FAIL;
    }
    m_display = VaapiDisplay::create(display);
    if (!m_display) {
        ERROR("failed to create display");
        return YAMI_DRIVER_FAIL;
    }

    ConfigPtr config = VaapiConfig::create(m_display, VAProfileNone, VAEntrypointVideoProc, NULL, 0);
    if (!config) {
        ERROR("failed to create config");
        return YAMI_NO_CONFIG;
    }

    //register WxH as 1x1 to make configure creation not fail.
    m_context = VaapiContext::create(config,1, 1,
                                     0, NULL, 0);
    if (!m_context) {
        ERROR("failed to create context");
        return YAMI_FAIL;
    }
    return YAMI_SUCCESS;
}

void VaapiPostProcessBase::cleanupVA()
{
    m_context.reset();
    m_display.reset();
}

VaapiPostProcessBase::~VaapiPostProcessBase()
{
    cleanupVA();
}

}

==> libyami-0.4.0.tar.gz: libyami-libyami-0.4.0/vpp/vaapipostprocess_base.cpp <==
/*
 * Copyright (C) 2013-2014 Intel Corporation. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "vaapipostprocess_base.h"
#include "common/log.h"
#include "vaapi/vaapidisplay.h"
#include "vaapi/vaapicontext.h"
#include "vaapi/VaapiUtils.h"

namespace YamiMediaCodec{

YamiStatus  VaapiPostProcessBase::setNativeDisplay(const NativeDisplay& display)
{
    return initVA(display);
}

YamiStatus VaapiPostProcessBase::initVA(const NativeDisplay& display)
{
    if (m_context) {
        ERROR("do not init va more than one time");
        return YAMI_FAIL;
    }
    if (display.type != NATIVE_DISPLAY_VA
        || !display.handle) {
        ERROR("vpp only support va display as NativeDisplay");
        return YAMI_FAIL;
    }
    m_display = VaapiDisplay::create(display);
    if (!m_display) {
        ERROR("failed to create display");
        return YAMI_DRIVER_FAIL;
    }

    ConfigPtr config = VaapiConfig::create(m_display, VAProfileNone, VAEntrypointVideoProc, NULL, 0);
    if (!config) {
        ERROR("failed to create config");
        return YAMI_NO_CONFIG;
    }

    //register WxH as 1x1 to make configure creation not fail.
    m_context = VaapiContext::create(config,1, 1,
                                     0, NULL, 0);
    if (!m_context) {
        ERROR("failed to create context");
        return YAMI_FAIL;
    }
    return YAMI_SUCCESS;
}

void VaapiPostProcessBase::cleanupVA()
{
    m_context.reset();
    m_display.reset();
}

VaapiPostProcessBase::~VaapiPostProcessBase()
{
    cleanupVA();
}

}
